<template>
    <div class="system-role-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <div class="basic-line">
                    <span>整改类型：</span>
                    <el-select class="input-box" v-model="checkData.params.rectifyType" placeholder="整改类型" filterable>
                        <el-option v-for="item in rectifyTypeList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>整改部门：</span>
                    <el-cascader :options="departmentList" :props="{ emitPath: false, checkStrictly: true, value: 'depId', label: 'depName' }" placeholder="请选择部门" clearable filterable class="input-box" v-model="checkData.params.rectifyDepId"> </el-cascader>
                </div>

                <el-button size="default" type="primary" class="ml10" v-throttle @click="handleSearch">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
            </div>
            <el-table :data="checkData.data" style="width: 100%" fit highlight-current-row>
                <el-table-column type="index" label="序号" width="60" />
                <el-table-column prop="rectifyDesc" label="整改内容说明" show-overflow-tooltip min-width="150px"></el-table-column>
                <el-table-column prop="applyTime" label="整改时间" show-overflow-tooltip min-width="150px"></el-table-column>
                <el-table-column prop="rectifyType" label=" 整改类型" show-overflow-tooltip min-width="150px">
                    <template #default="scope">
                        {{ parseNumber(scope.row.rectifyType, '整改类型') }}
                    </template>
                </el-table-column>
                <el-table-column prop="liablePerson" label="整改责任人" show-overflow-tooltip min-width="150px"></el-table-column>
                <el-table-column prop="cost" label="整改资金" show-overflow-tooltip min-width="150px"></el-table-column>
                <el-table-column prop="dangerStatus" label="验收状态" show-overflow-tooltip min-width="150px" align="center">
                    <template #default="scope">
                        <el-tag :type="scope.row.dangerStatus === 0 ? 'info' : scope.row.dangerStatus === 1 ? 'primary' : scope.row.dangerStatus === 2 ? 'warning' : scope.row.dangerStatus === 4 ? 'danger' : 'success'">
                            {{ parseNumber(scope.row.dangerStatus, '隐患整改状态') }}
                        </el-tag>
                    </template>
                </el-table-column>
                <el-table-column prop="checkAcceptPerson" label="验收人" show-overflow-tooltip min-width="150px"></el-table-column>
                <el-table-column label="操作" width="250" fixed="right" align="center">
                    <template #default="scope">
                        <el-button size="small" text type="primary" :icon="View" @click="onOpenDialogRef('查看', scope.row)">查看</el-button>
                        <el-button size="small" text type="primary" :icon="Check" v-show="scope.row.dangerStatus === 1" @click="onOpenDialogRef('验收', scope.row)">验收</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="checkData.params.pageIndex" background v-model:page-size="checkData.params.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="checkData.total" class="page-position"> </el-pagination>
            <br />
            <br />
        </el-card>
        <checkDialog ref="checkDialogRef" @refreshCheck="initCheckTableData" />
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import checkDialog from './components/checkDialog.vue';
import { Check, Delete, View } from '@element-plus/icons-vue';
import { departmentApi } from '/@/api/systemManage/department';
import { hiddenCheckApi } from '/@/api/doublePreventSystem/check';

// 定义接口来定义对象的类型
interface TableData {
    quota: string;
    quotaUnit: string;
    quotaType: string;
    createUserName: string;
    gmtCreate: string;
    lastEditUserName: string;
    gmtModitify: string;
}
interface TableDataState {
    checkData: {
        data: Array<TableData>;
        total: number;
        loading: boolean;
        params: {
            pageIndex: number;
            pageSize: number;
            rectifyType: number | null;
            rectifyDepId: number | null;
            dangerStatus: number | null;
        };
    };
    rectifyTypeList: Array<enumType>;
    dangerStatusList: Array<enumType>;
    departmentList: [];
}
interface enumType {
    id: number;
    name: string;
}

export default defineComponent({
    name: 'check',
    components: { checkDialog, Check, Delete, View },
    setup() {
        const checkDialogRef = ref();
        const state = reactive<TableDataState>({
            checkData: {
                data: [],
                total: 0,
                loading: false,
                params: {
                    pageIndex: 1,
                    pageSize: 10,
                    rectifyType: null,
                    rectifyDepId: null,
                    dangerStatus: 1
                }
            },
            departmentList: [],
            rectifyTypeList: [
                { id: 1, name: '即查即改' },
                { id: 2, name: '限期整改' }
            ],
            dangerStatusList: [
                { id: 0, name: '整改中' },
                { id: 1, name: '待验收' },
                { id: 2, name: '延期整改' },
                { id: 4, name: '超期未整改' },
                { id: 9, name: '已验收' }
            ]
        });

        // 初始化表格数据
        const initCheckTableData = async () => {
            let res = await hiddenCheckApi().getHiddenCheckList(state.checkData.params);
            if (res.data.code === '200') {
                state.checkData.data = res.data.data;
                state.checkData.total = res.data.count;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        //获取部门列表
        const getDepartmentData = async () => {
            let res = await departmentApi().getDepartmentList();
            if (res.data.code === '200') {
                state.departmentList = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 打开弹窗
        const onOpenDialogRef = (type: string, value: any) => {
            checkDialogRef.value.openCheckDialog(type, value, state.departmentList);
        };

        const parseNumber = (value: string | number, type: string) => {
            if (type === '整改类型') {
                return state.rectifyTypeList.find((item) => item.id === value)?.name;
            } else if (type === '隐患整改状态') {
                return state.dangerStatusList.find((item) => item.id === value)?.name;
            }
        };

        const handleSearch = () => {
            initCheckTableData();
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.checkData.params.pageSize = val;
            initCheckTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.checkData.params.pageIndex = val;
            initCheckTableData();
        };
        // 页面加载时
        onMounted(() => {
            initCheckTableData();
            getDepartmentData();
        });

        return {
            Check,
            Delete,
            View,
            parseNumber,
            handleSearch,
            onOpenDialogRef,
            onHandleSizeChange,
            onHandleCurrentChange,
            checkDialog,
            checkDialogRef,
            initCheckTableData,
            ...toRefs(state)
        };
    }
});
</script>

<style scoped></style>
